# Configuration et procédures d'exploitation

## Configuration de l'application

Le mode "Configuration" permet d'éditer les paramètres de configuration stockés dans des fichiers de type "properties" et de consulter l'état de l'application.

### Paramètres généraux de configuration

La section "Configuration" permet de consulter et modifier les paramètres généraux de l'application. Organisée en rubriques cette section permet l'édition des paramètres généraux de l'application, des serveurs HTTP, des paramètres de gestion d'écriture des logs et de sécurité, et la consultation des informations relatives à la base de données.

 ![](../images/icones/warning.png)
La taille maximale de fichier uploadé est définie par défaut à 100 Mo. Pour augmenter cette valeur, il est nécessaire de modifier les deux properties "upload_max_filesize" et "post_max_size" du fichier de configuration php.ini avant de configurer cette valeur directement dans le mode configuration de GTF.


L'administrateur personnalise l'application et améliore ses performances en déterminant les délais d'expiration de l'interface graphique, les taillles maximales des fichiers uploadés sur le serveur, ainsi que le type fichiers interdits...

 Il définit également l'emplacement du répertoire temporaire exploité par GTF

#### Stratégie de sécurité : configuration du compte public et gestion des groupes

La partie "Sécurité" de la section "Configuration" permet de définir un compte de connexion public pour lequel un jeton de connexion doit être associé.

Le jeton de connexion est l'identifiant de connexion appelant un service GTF, intégré directement dans une page Internet. Créer un compte public avec son jeton de connexion est un moyen simple pour un administrateur de donner accès à un formulaire GTF à un utilisateur avec un minimum de droits.

L'administrateur choisit dans la liste déroulante quel compte est le compte public, il saisit ensuite son mot de passe, puis nomme le jeton tel qu'il le souhaite :

 ![](../images/icones/warning.png) Le jeton de connexion public doit être une chaîne de caractères non vide et sans espace.

 ![](../images/03000049_503x169.png)




Le bouton **Autoriser les connexions avec le compte PUBLIC** permet d'activer/désactiver l'accès aux services GTF du compte PUBLIC.

La partie "Sécurité" de la section "Sécurité" permet la configuration de la gestion mixte des utilisateurs.

#### Gestion des journaux

Cette section permet de définir les journaux à générer, la période de journalisation ainsi que la taille maximale en Ko d'un fichier de log au delà de laquelle ce dernier ne pourra s'afficher dans l'interface.

### Version des composants

La section Version permet de consulter le numéro de version de GTF et le build installé. L'état des composants installés est consultables ainsi que les informations relatives au serveur et serveur web.

### Informations PHP

La section "PHP Info" permet de consulter les paramètres de la version PHP installée.

### Fichier de licence FME

Cette section "Licence" permet de faire une demande de fichier de licence, de l'installer puis de l'activer.

Le bouton **Demande de fichier de licence** permet d'envoyer au service administratif de Veremes une demande de génération de fichier de licence. Indiquer le numéro de licence fourni dans l'accusé de réception de votre commande, ainsi que l'adresse mail à laquelle le fichier doit être envoyé.

Une fois obtenu, indiquer l'emplacement du fichier de licence délivré par Veremes dans le champ "Fichier .txt", puis cliquer sur **Activer**.

### Configuration du module GTF

 Cette section permet l'édition des paramètres de configuration spécifiques au module GTF.

Le répertoire du Pycron est à définir dans le champ "Répertoire de Pycron", ainsi que le modèle d'e-mail utilisé par défaut pour l'envoi des notifications des résultats des traitements.

On peut exclure des formats de la compression en définissant les extensions de fichiers non compressibles.

 ![](../images/icones/warning.png) Les formats de fichiers uniques tels que .xls, .html, .htm sont par défaut non compressibles.



#### Configuration du serveur SMTP

Les paramètres du serveur SMTP sont configurables dans cette rubrique.

L'adresse mail et le nom de l'expéditeur des mails de notification sont définis ainsi que le nom du serveur SMTP et le port qu'il utilise.

L'authentification SMTP permet de définir si l'expéditeur peut envoyer des mails sans avoir à s'authentifier. Si une authentification est requise, alors le compte SMTP et le mot de passe SMTP doivent être renseignés.

#### Configuration des moteurs GTF

L'administrateur de GTF peut définir les heures creuses d'exécution des moteurs au format "hh:mm" ainsi que le nombre maximum de demandes exécutées en même temps.

----

## Configuration des répertoires Public et Upload

Les répertoires Upload et Public, installés dans le répertoire d'installation de GTF, stockent respectivement les ressources chargées avec un projet et les résultats d'un traitement. Il est possible de déplacer ces deux répertoires sur un autre disque et d'assurer de la sorte une répartition des données pour faciliter les processus de sauvegarde.

Pour cela, l'administrateur doit opérer en deux étapes :

- Dans le fichier de configuration "properties\_post.inc" du répertoire ".\gtf.client", modifier les deux properties suivantes en indiquant le chemin complet des répertoires upload et public :
 * $properties['upload\_dir'] = $properties['gtf\_home'] . '/upload';
 * $properties['dir\_export'] = $properties['gtf\_home'] . '/public';


- Dans le fichier de configuration "httpd.conf" du répertoire .\server\Apache2.4\conf du répertoire d'installation de GTF, modifier la configuration :
	* Alias /public "C:/serveur/gtf_2015-01.00.b12674_betax64/public" en indiquant le chemin complet
	* &lt;Directory C:/serveur/gtf_2015-01.00.b12674_betax64/public> en indiquant le chemin complet du répertoire public.

  ----

## Nettoyage et suppression des fichiers temporaires

L'administrateur doit veiller à supprimer régulièrement les fichiers temporaires générés par l'application.

Il dispose pour cela du projet FME "nettoyage\_des\_fichiers\_temporaires.fmw" contenu dans le fichier "admin.gex", disponible sur [notre site de téléchargement](http://download.veremes.com/). Après avoir importé et publié ce projet dans GTF, l'administrateur peut s'abonner au traitement et assurer de la sorte une suppression régulière des fichiers temporaires.

3 types de fichiers peuvent être supprimés :
- Les fichiers temporaires produits par GTF
- Les fichiers temporaires produits par FME
- Les jeux de données sources chargés sur le serveur par les utilisateurs finaux contenus dans le répertoire &lt;gtf>\upload

Le paramètre "Age minimum des fichiers à supprimer" permet de définir l'ancienneté minimale (en jours) des fichiers à supprimer évitant ainsi la suppression de fichiers déposés sur le serveur sans avoir été traités ou en cours d'exécution.

Un rapport de nettoyage dont le nom est défini par l'utilisateur est généré au format.txt.
